@@ -7,6 +7,8 @@ from sqlalchemy.types import JSON
 
 
 class build_object(FunctionElement):
+    """JSON object creation"""
+
     type = JSON()
     name = "jsonb_build_object"
 
@@ -15,7 +17,7 @@ class build_object(FunctionElement):
 def pg_build_object(
     element: build_object, compiler: SQLCompiler, **kw: Dict[str, Any]
 ) -> SQLCompiler:
-    return compiler.visit_function(element)
+    return "jsonb_build_object(%s)" % compiler.process(element.clauses, **kw)
 
 
 @compiles(build_object, "sqlite")
